@@ -8,10 +8,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     Revised BSD License for more details.
 
-    Copyright 2004-2019 iDB Support - https://idb.osdn.jp/support/category.php?act=view&id=1
-    Copyright 2004-2019 Game Maker 2k - https://idb.osdn.jp/support/category.php?act=view&id=2
+    Copyright 2004-2023 iDB Support - https://idb.osdn.jp/support/category.php?act=view&id=1
+    Copyright 2004-2023 Game Maker 2k - https://idb.osdn.jp/support/category.php?act=view&id=2
 
-    $FileInfo: html5.php - Last Update: 11/27/2020 SVN 928 - Author: cooldude2k $
+    $FileInfo: html5.php - Last Update: 6/16/2023 SVN 973 - Author: cooldude2k $
 */
 $File3Name = basename($_SERVER['SCRIPT_NAME']);
 if ($File3Name=="html5.php"||$File3Name=="/html5.php") {
@@ -176,6 +176,7 @@ if($XHTML5===false) { ?>
 <meta charset="<?php echo $Settings['charset']; ?>">
 <meta http-equiv="Content-Type" content="text/html; charset=<?php echo $Settings['charset']; ?>">
 <meta name="language" content="english">
+<meta name="viewport" content="width=device-width initial-scale=1.0">
 <?php 
 if(!isset($_SERVER['HTTP_USER_AGENT'])) {
 	$_SERVER['HTTP_USER_AGENT'] = ""; }
@@ -228,7 +229,7 @@ ob_start("idb_suboutput_handler"); ?>
 <!-- generator="<?php echo $iDB; ?>" -->
 <?php } $iWrappers['METATAGS'] = ob_get_clean(); 
 ob_start("idb_suboutput_handler"); ?>
-<link rel="preload" as="script" href=<?php echo url_maker($exfilejs['javascript'],$Settings['js_ext'],null,$Settings['qstr'],$Settings['qsep'],$prexqstrjs['javascript'],$exqstrjs['javascript']); ?>" />
+<link rel="preload" as="script" href="<?php echo url_maker($exfilejs['javascript'],$Settings['js_ext'],null,$Settings['qstr'],$Settings['qsep'],$prexqstrjs['javascript'],$exqstrjs['javascript']); ?>" />
 <script type="text/javascript" src="<?php echo url_maker($exfilejs['javascript'],$Settings['js_ext'],null,$Settings['qstr'],$Settings['qsep'],$prexqstrjs['javascript'],$exqstrjs['javascript']); ?>"></script>
 <script type="text/javascript">
  var tzname=Intl.DateTimeFormat().resolvedOptions().timeZone;
