@@ -8,10 +8,10 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     Revised BSD License for more details.
 
-    Copyright 2004-2019 iDB Support - https://idb.osdn.jp/support/category.php?act=view&id=1
-    Copyright 2004-2019 Game Maker 2k - https://idb.osdn.jp/support/category.php?act=view&id=2
+    Copyright 2004-2023 iDB Support - https://idb.osdn.jp/support/category.php?act=view&id=1
+    Copyright 2004-2023 Game Maker 2k - https://idb.osdn.jp/support/category.php?act=view&id=2
 
-    $FileInfo: versioninfo.php - Last Update: 4/4/2022 SVN 943 - Author: cooldude2k $
+    $FileInfo: versioninfo.php - Last Update: 6/16/2023 SVN 973 - Author: cooldude2k $
 */
 $File3Name = basename($_SERVER['SCRIPT_NAME']);
 if ($File3Name=="versioninfo.php"||$File3Name=="/versioninfo.php") {
@@ -26,9 +26,9 @@ function version_info($proname,$subver,$ver,$supver,$reltype,$svnver,$showsvn) {
 	if($showsvn!==true&&$showsvn!==null) { $return_var .= " ".$showsvn." ".$svnver; }
 	return $return_var; }
 // Version number and date stuff. :P
-$VER1[0] = 0; $VER1[1] = 5; $VER1[2] = 4; $VERFull[1] = $VER1[0].".".$VER1[1].".".$VER1[2];
-$VER2[0] = "Alpha"; $VER2[1] = "Al"; $VER2[2] = "SVN"; $SubVerN = 943; $GitRevN = "$Id: a313442b18e24a2d482c963ad4b3392d180d5d32 $";
-$SVNDay[0] = 4; $SVNDay[1] = 4; $SVNDay[2] = 2022; $SVNDay[3] = $SVNDay[0]."/".$SVNDay[1]."/".$SVNDay[2];
+$VER1[0] = 0; $VER1[1] = 5; $VER1[2] = 8; $VERFull[1] = $VER1[0].".".$VER1[1].".".$VER1[2];
+$VER2[0] = "Alpha"; $VER2[1] = "Al"; $VER2[2] = "SVN"; $SubVerN = 973; $GitRevN = '$Id: 8afc71332050389f79db5a5b409570559f8571b7 $';
+$SVNDay[0] = 4; $SVNDay[1] = 16; $SVNDay[2] = 2022; $SVNDay[3] = $SVNDay[0]."/".$SVNDay[1]."/".$SVNDay[2];
 $AltName = "DF2k"; $AltName2 = "DF2k"; $RName = "iDB"; $SFName = "IntDB";
 $RFullName = "Internet Discussion Boards"; $AltFullName = "Discussion Forums 2k"; $AltGM2k = "Game Maker 2k";
 $VerCheckName = "iDB"; $AltVerCheckName = "DF2k"; $AltiDBHome = "https://idb.osdn.jp/";
@@ -99,7 +99,8 @@ $VerCheckQuery = $VerCheckQuery['query'];
 if($VerCheckQuery=="") { $VerCheckURL = $VerCheckURL."?"; }
 if(!isset($Settings['IPCheckURL'])||
 	$Settings['IPCheckURL']==="") {
-$IPCheckURL = 'http://cqcounter.com/whois/?query=%s'; }
+//$IPCheckURL = 'http://cqcounter.com/whois/?query=%s';
+$IPCheckURL = 'https://tools.keycdn.com/geo?host=%s'; }
 if(isset($Settings['IPCheckURL'])&&
 	$Settings['IPCheckURL']!=="") {
 $IPCheckURL = $Settings['IPCheckURL']; }
